@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Draw fretboard chord diagrams
 
-our $VERSION = '0.1207';
+our $VERSION = '0.1300';
 
 use Moo;
 use strictures 2;
@@ -61,7 +61,7 @@ has type => (
 
 has font => (
     is      => 'ro',
-    default => sub { '/opt/X11/share/fonts/TTF/VeraMono.ttf' },
+    default => sub { '/usr/share/fonts/truetype/freefont/FreeMono.ttf' },
 );
 
 
@@ -122,8 +122,11 @@ has fretboard => (
 sub BUILD {
     my ( $self, $args ) = @_;
 
+    $self->chord( [ [ $self->position, $self->chord ] ] )
+        unless ref $self->chord;
+
     die 'chord length and string number differ'
-        if $args->{chord} && length($args->{chord}) != $self->{strings};
+        if $self->chord && length( $self->chord->[0][1] ) != $self->strings;
 
     my @scale = qw/C Db D Eb E F Gb G Ab A Bb B/;
 
@@ -154,7 +157,6 @@ sub draw {
     my $TAN   = 'tan';
     my $SPACE = $self->size;
 
-    my @chord;
     my $font;
 
     # Setup a new image
@@ -219,70 +221,80 @@ sub draw {
         );
     }
 
-    # Draw the note/mute markers
-    my $string = $self->strings;
+    for my $spec ( @{ $self->chord } ) {
+        my ( $posn, $chord ) = @$spec;
 
-    for my $note ( split //, $self->chord ) {
-        if ( $note =~ /[xX]/ ) {
-            print "X at 0,$string\n" if $self->verbose;
+        my @chord;
 
+        # Draw the note/mute markers
+        my $string = $self->strings;
+        for my $note ( split //, $chord ) {
+            if ( $note =~ /-/ ) {
+                $string--;
+                next;
+            }
+
+            if ( $note =~ /[xX]/ ) {
+                print "X at 0,$string\n" if $self->verbose;
+
+                $i->string(
+                    font  => $font,
+                    text  => 'X',
+                    color => $BLACK,
+                    x     => $SPACE + ($self->strings - $string) * $SPACE - $SPACE / 6,
+                    y     => $SPACE - 2,
+                    size  => $SPACE / 2,
+                    aa    => 1,
+                );
+            }
+            elsif ( $note =~ /[oO0]/ ) {
+                my $temp = $self->fretboard->{$string}[0];
+                push @chord, $temp;
+
+                print "O at 0,$string = $temp\n" if $self->verbose;
+
+                $i->string(
+                    font  => $font,
+                    text  => 'O',
+                    color => $BLACK,
+                    x     => $SPACE + ($self->strings - $string) * $SPACE - $SPACE / 6,
+                    y     => $SPACE - 2,
+                    size  => $SPACE / 2,
+                    aa    => 1,
+                );
+            }
+            else {
+                my $temp = $self->_note_at($string, $note);
+                push @chord, $temp;
+
+                print "Dot at $note,$string = $temp\n" if $self->verbose;
+
+                $i->circle(
+                    color => $self->dot_color,
+                    r     => $SPACE / 5,
+                    x     => $SPACE + ($self->strings - $string) * $SPACE,
+                    y     => $SPACE + $SPACE / 2 + ($posn - 1 + $note - 1) * $SPACE,
+                );
+            }
+
+            # Decrement the current string number
+            $string--;
+        }
+
+        # Print the chord name if requested
+        if ( $self->showname ) {
+            my $chord_name = $self->showname eq '1' ? chordname(@chord) : $self->showname;
+            print "Chord = $chord_name\n" if $self->verbose;
             $i->string(
                 font  => $font,
-                text  => 'X',
+                text  => $chord_name,
                 color => $BLACK,
-                x     => $SPACE + ($self->strings - $string) * $SPACE - $SPACE / 6,
-                y     => $SPACE - 2,
+                x     => $SPACE,
+                y     => ($self->frets + 1) * $SPACE - $SPACE / 3,
                 size  => $SPACE / 2,
                 aa    => 1,
             );
         }
-        elsif ( $note =~ /[oO0]/ ) {
-            my $temp = $self->fretboard->{$string}[0];
-            push @chord, $temp;
-
-            print "O at 0,$string = $temp\n" if $self->verbose;
-
-            $i->string(
-                font  => $font,
-                text  => 'O',
-                color => $BLACK,
-                x     => $SPACE + ($self->strings - $string) * $SPACE - $SPACE / 6,
-                y     => $SPACE - 2,
-                size  => $SPACE / 2,
-                aa    => 1,
-            );
-        }
-        else {
-            my $temp = $self->_note_at($string, $note);
-            push @chord, $temp;
-
-            print "Dot at $note,$string = $temp\n" if $self->verbose;
-
-            $i->circle(
-                color => $self->dot_color,
-                r     => $SPACE / 5,
-                x     => $SPACE + ($self->strings - $string) * $SPACE,
-                y     => $SPACE + $SPACE / 2 + ($note - 1) * $SPACE,
-            );
-        }
-
-        # Decrement the current string number
-        $string--;
-    }
-
-    # Print the chord name if requested
-    if ( $self->showname ) {
-        my $chord_name = $self->showname eq '1' ? chordname(@chord) : $self->showname;
-        print "Chord = $chord_name\n" if $self->verbose;
-        $i->string(
-            font  => $font,
-            text  => $chord_name,
-            color => $BLACK,
-            x     => $SPACE,
-            y     => ($self->frets + 1) * $SPACE - $SPACE / 3,
-            size  => $SPACE / 2,
-            aa    => 1,
-        );
     }
 
     if ( $self->image ) {
@@ -301,7 +313,6 @@ sub _draw_horiz {
     my $TAN   = 'tan';
     my $SPACE = $self->size;
 
-    my @chord;
     my $font;
 
     # Setup a new image
@@ -366,70 +377,77 @@ sub _draw_horiz {
         );
     }
 
-    # Draw the note/mute markers
-    my $string = 1;
+    for my $spec ( @{ $self->chord } ) {
+        my ( $posn, $chord ) = @$spec;
 
-    for my $note ( reverse split //, $self->chord ) {
-        if ( $note =~ /[xX]/ ) {
-            print "X at fret:0, string:$string\n" if $self->verbose;
+        my @chord;
 
+        # Draw the note/mute markers
+        my $string = 1;
+        for my $note ( reverse split //, $chord ) {
+            next if $note =~ /-/;
+
+            if ( $note =~ /[xX]/ ) {
+                print "X at fret:0, string:$string\n" if $self->verbose;
+
+                $i->string(
+                    font  => $font,
+                    text  => 'X',
+                    color => $BLACK,
+                    y     => $SPACE + ($string - 1) * $SPACE + $SPACE / 4,
+                    x     => $SPACE - $SPACE / 2,
+                    size  => $SPACE / 2,
+                    aa    => 1,
+                );
+            }
+            elsif ( $note =~ /[oO0]/ ) {
+                my $temp = $self->fretboard->{$string}[0];
+                unshift @chord, $temp;
+
+                print "O at fret:0, string:$string = $temp\n" if $self->verbose;
+
+                $i->string(
+                    font  => $font,
+                    text  => 'O',
+                    color => $BLACK,
+                    y     => $SPACE + ($string - 1) * $SPACE + $SPACE / 4,
+                    x     => $SPACE - $SPACE / 2,
+                    size  => $SPACE / 2,
+                    aa    => 1,
+                );
+            }
+            else {
+                my $temp = $self->_note_at($string, $note);
+                unshift @chord, $temp;
+
+                print "Dot at fret:$note, string:$string = $temp\n" if $self->verbose;
+
+                $i->circle(
+                    color => $self->dot_color,
+                    r     => $SPACE / 5,
+                    y     => $SPACE + ($string - 1) * $SPACE,
+                    x     => $SPACE + $SPACE / 2 + ($posn - 1 + $note - 1) * $SPACE,
+                );
+            }
+
+            # Increment the current string number
+            $string++;
+        }
+
+        # Print the chord name if requested
+        if ( $self->showname ) {
+            my $chord_name = $self->showname eq '1' ? chordname(@chord) : $self->showname;
+            print "Chord = $chord_name\n" if $self->verbose;
             $i->string(
                 font  => $font,
-                text  => 'X',
+                text  => $chord_name,
                 color => $BLACK,
-                y     => $SPACE + ($string - 1) * $SPACE + $SPACE / 4,
-                x     => $SPACE - $SPACE / 2,
+                x     => $SPACE,
+                y     => ($self->strings + 1) * $SPACE - $SPACE / 3,
                 size  => $SPACE / 2,
                 aa    => 1,
             );
         }
-        elsif ( $note =~ /[oO0]/ ) {
-            my $temp = $self->fretboard->{$string}[0];
-            unshift @chord, $temp;
-
-            print "O at fret:0, string:$string = $temp\n" if $self->verbose;
-
-            $i->string(
-                font  => $font,
-                text  => 'O',
-                color => $BLACK,
-                y     => $SPACE + ($string - 1) * $SPACE + $SPACE / 4,
-                x     => $SPACE - $SPACE / 2,
-                size  => $SPACE / 2,
-                aa    => 1,
-            );
-        }
-        else {
-            my $temp = $self->_note_at($string, $note);
-            unshift @chord, $temp;
-
-            print "Dot at fret:$note, string:$string = $temp\n" if $self->verbose;
-
-            $i->circle(
-                color => $self->dot_color,
-                r     => $SPACE / 5,
-                y     => $SPACE + ($string - 1) * $SPACE,
-                x     => $SPACE + $SPACE / 2 + ($note - 1) * $SPACE,
-            );
-        }
-
-        # Increment the current string number
-        $string++;
-    }
-
-    # Print the chord name if requested
-    if ( $self->showname ) {
-        my $chord_name = $self->showname eq '1' ? chordname(@chord) : $self->showname;
-        print "Chord = $chord_name\n" if $self->verbose;
-        $i->string(
-            font  => $font,
-            text  => $chord_name,
-            color => $BLACK,
-            x     => $SPACE,
-            y     => ($self->strings + 1) * $SPACE - $SPACE / 3,
-            size  => $SPACE / 2,
-            aa    => 1,
-        );
     }
 
     if ( $self->image ) {
@@ -485,14 +503,21 @@ Music::FretboardDiagram - Draw fretboard chord diagrams
 
 =head1 VERSION
 
-version 0.1207
+version 0.1300
 
 =head1 SYNOPSIS
 
   use Music::FretboardDiagram;
 
   my $dia = Music::FretboardDiagram->new(
-    chord   => 'x02220',
+    chord   => 'xx0232',
+    frets   => 1,
+    outfile => 'Dm',
+    font    => '/path/to/TTF/font.ttf',
+  );
+
+  $dia = Music::FretboardDiagram->new(
+    chord   => [[1,'022000'], [2,'--1342'], [7,'-13321']], # Em chords
     frets   => 13,
     outfile => 'fretboard',
     font    => '/path/to/TTF/font.ttf',
@@ -525,14 +550,21 @@ ukulele diagram:
 =head2 chord
 
   $dia->chord('xx0232');
+  $dia->chord([[1,'022000'], [2,'--1342'], [7,'-13321']]);
   $chord = $dia->chord;
 
-A required chord given as a string, where non-zero digits represent
-frets, C<x> (or C<X>) indicates a muted string and C<0> (or C<o> or
-C<O>) indicates an open string.  The default order of the strings is
-C<654321> from lowest to highest.
+A required chord given as a string or array reference of
+specifications.
 
-Examples:
+For a chord string, non-zero digits represent frets, C<x> (or C<X>)
+indicates a muted string, C<0> (or C<o> or C<O>) indicates an open
+string, and a dash (C<->) means skip to the next string.  The default
+order of the strings is C<654321> from lowest to highest.
+
+For an array-ref of chord specifications, the first element is the
+chord position, and the second is the chord string.
+
+Chord string examples:
 
   C: x32010
   D: xx0232
@@ -738,7 +770,7 @@ Create a new C<Music::FretboardDiagram> object.
 Render the requested chord diagram as an image file of the given
 B<type>.
 
-If the C<image> attribute is set, return the image object instead of
+If the B<image> attribute is set, return the image object instead of
 writing to a file.
 
 =head1 THANK YOU
